about summary refs log tree commit
path: root/lib/Net/Domain.pm
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Net/Domain.pm')
-rw-r--r--lib/Net/Domain.pm12
1 files changed, 7 insertions, 5 deletions
diff --git a/lib/Net/Domain.pm b/lib/Net/Domain.pm
index 41d49c3..3109f43 100644
--- a/lib/Net/Domain.pm
+++ b/lib/Net/Domain.pm
@@ -4,8 +4,9 @@
 # All rights reserved.
 # Changes in Version 2.22 onwards Copyright (C) 2013-2014 Steve Hay.  All rights
 # reserved.
# This program is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
 
 package Net::Domain;
 
@@ -20,7 +21,7 @@ use Net::Config;
 
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(hostname hostdomain hostfqdn domainname);
-our $VERSION = "3.04";
+our $VERSION = "3.07";
 
 my ($host, $domain, $fqdn) = (undef, undef, undef);
 
@@ -356,7 +357,8 @@ Versions up to 2.21 Copyright (c) 1995-1998 Graham Barr. All rights reserved.
 Changes in Version 2.22 onwards Copyright (C) 2013-2014 Steve Hay.  All rights
 reserved.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it under the
+same terms as Perl itself, i.e. under the terms of either the GNU General Public
+License or the Artistic License, as specified in the F<LICENCE> file.
 
 =cut
@@ -4,8 +4,9 @@
 # Changes in Version 2.22 onwards Copyright (C) 2013-2014 Steve Hay.  All rights
 # reserved.
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl itself.
+# This module is free software; you can redistribute it and/or modify it under
+# the same terms as Perl itself, i.e. under the terms of either the GNU General
+# Public License or the Artistic License, as specified in the F<LICENCE> file.
 
 package Net::Domain;